@@ -51,54 +51,12 @@ ClassErrorbar=function(Xvalues,Ymatrix,Cls,ClassNames,ClassCols,ClassShape,MeanF
     ClassCols=c(def,Cols)[1:length(u)]
   }
   #robust estimation of standard deviation
-  stdrobust=function (x, lowInnerPercentile = 25) {
-    prctile= function (x, p) 
-    {
-      if (length(p) == 1) {
-        if (p >= 1) {
-          p = p/100
-        }
-      }
-      if (max(p) >= 1) 
-        p = p/100
-      if (is.matrix(x) && ncol(x) > 1) {
-        cols <- ncol(x)
-        quants <- matrix(0, nrow = length(p), ncol = cols)
-        for (i in 1:cols) {
-          quants[, i] <- quantile(x[, i], probs = p, type = 5, 
-                                  na.rm = TRUE)
-        }
-      }
-      else {
-        quants <- quantile(x, p, type = 5, na.rm = TRUE)
-      }
-      return(quants)
-    }
-    
-    if (is.vector(x) || (is.matrix(x) && dim(x)[1] == 1)) 
-      dim(x) <- c(length(x), 1)
-    lowInnerPercentile <- max(1, min(lowInnerPercentile, 49))
-    hiInnerPercentile <- 100 - lowInnerPercentile
-    faktor <- sum(abs(qnorm(c(lowInnerPercentile, hiInnerPercentile)/100, 
-                            0, 1)))
-    std <- sd(x, na.rm = TRUE)
-    quartile <- prctile(x, c(lowInnerPercentile, hiInnerPercentile))
-    if (ncol(x) > 1) 
-      iqr <- quartile[2, ] - quartile[1, ]
-    else iqr <- quartile[2] - quartile[1]
-    shat <- c()
-    for (i in 1:ncol(x)) {
-      shat[i] <- min(c(std[i], iqr[i]/faktor), na.rm = TRUE)
-    }
-    dim(shat) <- c(1, ncol(x))
-    colnames(shat) <- colnames(x)
-    return(shat)
-  }
+
   
   sdrobust_hlp=function(x,na.rm){
     if(na.rm) x=x[is.finite(x)]
     
-    stdrobust(x)
+    DataVisualizations::Stdrobust(x)
   }
   if(missing(SDfun)) SDfun=sdrobust_hlp
   
@@ -120,8 +78,8 @@ ClassErrorbar=function(Xvalues,Ymatrix,Cls,ClassNames,ClassCols,ClassShape,MeanF
   #   ggplot2::geom_point(ggplot2::aes(shape="Method", color="Method", size="Method"),position=pd, size=3)+
   #   ggplot2::scale_shape_manual(values=ClassShape)+
   #   ggplot2::scale_colour_manual(values =ClassCols)
-  ggobj=ggplot2::ggplot(df, ggplot2::aes_string(x="Xvalues", y="Yvalues", colour="Method", group="Method"))+geom_errorbar(data = df,ggplot2::aes_string(ymin="lower", ymax="upper",colour="Method"), lwd=Whisker_lwd,width=WhiskerWidth, position=pd)+
-    geom_point(ggplot2::aes_string(shape="Method", color="Method", size="Method"),position=pd, size=3)+
+  ggobj=ggplot2::ggplot(df, ggplot2::aes(x=.data$Xvalues, y=.data$Yvalues, colour=.data$Method, group=.data$Method))+geom_errorbar(data = df,ggplot2::aes(ymin=.data$lower, ymax=.data$upper,colour=.data$Method), lwd=Whisker_lwd,width=WhiskerWidth, position=pd)+
+    geom_point(ggplot2::aes(shape=.data$Method, color=.data$Method, size=.data$Method),position=pd, size=3)+
     scale_shape_manual(values=ClassShape)+
     scale_colour_manual(values =ClassCols)
   #setting labels and centering title
